﻿using System;
using System.Windows;

using ThinkGeo.Core;

namespace ThinkGeoCrash
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, IDisposable
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Add the OpenStreetMaps layer to the map
        /// </summary>
        private async void MapView_Loaded(object sender, RoutedEventArgs e)
        {
            // It is important to set the map unit first to either feet, meters or decimal degrees.
            MapView.MapUnit = GeographyUnit.Meter;

            // Set the zoom level set on the map to make sure its compatible with the OSM zoom levels.
            MapView.ZoomLevelSet = new OpenStreetMapsZoomLevelSet();

            // Create a new overlay that will hold our new layer and add it to the map and set the tile size to match up with the OSM til size.
            var layerOverlay = new LayerOverlay();
            MapView.Overlays.Add(layerOverlay);
            layerOverlay.TileWidth = 256;
            layerOverlay.TileHeight = 256;

            // Create the new layer and add it to the overlay.  We set the user agent to specify the requests are coming from our samples.
            // You need to change this to your application, so they can identify you for usage.
            var openStreetMapLayer = new OpenStreetMapAsyncLayer("ThinkGeo Samples/12.0 (http://thinkgeo.com/; system@thinkgeo.com)");

            openStreetMapLayer.ProjectionConverter = new GdalProjectionConverter(Projection.GetGoogleMapProjString(), "+proj=utm +zone=30 +datum=WGS84 +units=m +no_defs +type=crs");
            openStreetMapLayer.ProjectionConverter.Open();
            layerOverlay.Layers.Add(openStreetMapLayer);

            var point = new PointShape(475930.233468624, 6206959.17296505);
            await MapView.CenterAtAsync(point);
            await MapView.ZoomToAsync(point, 1);
            await MapView.RefreshAsync();
        }

        public void Dispose()
        {
            // Dispose of unmanaged resources.
            MapView.Dispose();
            // Suppress finalization.
            GC.SuppressFinalize(this);
        }
    }
}